<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:x="http://ai-and-it.de/xmlns/2020/xc"
  xmlns:xhtml="http://www.w3.org/1999/xhtml"
  xmlns="http://www.w3.org/1999/xhtml"
  version="1.0">

  <xsl:output method="xml" encoding="utf-8"/>

  <xsl:template match="text()"/>

  <xsl:template match="/">
    <div>
      <div class="xc-sl-poll"
	     data-poll-url="/main/get?path=files/xml/mainmenu.xml"
	     data-postprocess="xc.psHTML"
	     data-poll-interval="100000">
      </div>
      <h2 class="tlt">Measurement Process Control</h2>
      <div>
	<form class="inline-block" action="/main/action" method="post">
	  <input type="hidden" name="path" value="bin/start-measurement.sh"/>
	  <input class="tltv" type="submit" value="Start Measurement"/>
	  <input type="hidden" name="next_" value="/main/ajax_view?path=measurement.xml&amp;v=control-view"/>
	  <input type="hidden" name="csrfmiddlewaretoken" value="{//*/x:cgi/x:csrfmiddlewaretoken}"/>
	</form>
	<form class="inline-block" action="/main/action" method="post">
	  <input type="hidden" name="path" value="bin/stop-measurement.sh"/>
	  <input class="tltv" type="submit" value="Stop Measurement"/>
	  <input type="hidden" name="next_" value="/main/ajax_view?path=measurement.xml&amp;v=control-view"/>
	  <input type="hidden" name="csrfmiddlewaretoken" value="{//*/x:cgi/x:csrfmiddlewaretoken}"/>
	</form>
	<div>
	  <xsl:apply-templates select="//x:measurement/x:file"/>
	  <xsl:apply-templates select="//x:measurement/x:log"/>
	  <xsl:apply-templates select="//x:measurement/x:pid"/>
	</div>
      </div>
      <div>
	<h2 class="tlt">Device status</h2>
	<div>
	  <form class="inline-block" action="/main/action" method="post">
	    <input type="hidden" name="path" value="bin/shutdown.sh"/>
	    <input class="tltv" type="submit" value="Shut down uSense"/>
	    <input type="hidden" name="next_" value="/main/ajax_view?path=measurement.xml&amp;v=control-view"/>
	    <input type="hidden" name="csrfmiddlewaretoken" value="{//*/x:cgi/x:csrfmiddlewaretoken}"/>
	  </form>
	  <form class="inline-block" action="/main/action" method="post">
	    <input type="hidden" name="path" value="bin/reboot.sh"/>
	    <input class="tltv" type="submit" value="Restart uSense"/>
	    <input type="hidden" name="next_" value="/main/ajax_view?path=measurement.xml&amp;v=control-view"/>
	    <input type="hidden" name="csrfmiddlewaretoken" value="{//*/x:cgi/x:csrfmiddlewaretoken}"/>
	  </form>
	</div>
	<table>
	  <tr>
	    <td><span class="tlt">WiFi status</span>:</td>
	    <td>
	      <code class="xc-sl-poll pre mono" data-poll-url="/main/plain_status?path=bin/iwconfig.sh"
		    data-postprocess="xc.psHead(2)"
		    id="status-iwconfig"
		    data-poll-interval="3000">
	      </code>
	    </td>
	  </tr>
	  <tr>
	    <td><span class="tlt">Disk status</span>:</td>
	    <td>
	      <code class="xc-sl-poll pre mono" data-poll-url="/main/plain_status?path=bin/dfh.sh"
		    data-postprocess="xc.psHead(2)"
		    id="status-dfh"
		    data-poll-interval="3000">
	      </code>
	    </td>
	  </tr>
	</table>
      </div>
    </div>
  </xsl:template>

  <xsl:template match="x:file">
    <div>
	<span class="tlt">Result file</span>
	<xsl:text>: </xsl:text>
	<xsl:value-of select="."/>
    </div>
  </xsl:template>

  <xsl:template match="x:log">
    <div class="measurement-log">
      <span class="tlt">Log file <xsl:value-of select="."/></span>
      <xsl:text> </xsl:text>
      <a class="xc-nocatch" href="/main/getf/{.}">Download</a>
      <br/>
      <code class="xc-sl-poll pre" data-poll-url="/main/tail?path={.}&amp;n=4"
	  data-postprocess="psText"
	  id="meas-log"
	  data-poll-interval="1000">
      </code>
    </div>
  </xsl:template>

  <xsl:template match="x:pid">
    <div class="measurement-process">
      <table>
	<tr>
	  <th>PID</th><th>CPU (%)</th><th><span class="tlt">Memory</span> (%)</th><th class="tlt">Duration</th>
	  <th class="tlt">CPU time</th><th class="tlt">State</th>
	</tr>
	<xsl:for-each select="../x:pids/x:pid">
	  <tr class="xc-sl-poll"
	      data-poll-url="/main/plain_ps?pid={.}&amp;fields=pid&amp;fields=pcpu&amp;fields=pmem&amp;fields=etime&amp;fields=time&amp;fields=s"
	      id="meas-ps-info-{.}"
	      data-postprocess="meas.psMultiField"
	      data-poll-method="post"
	      data-poll-interval="1000">
	    <td>Test</td>
	  </tr>
	</xsl:for-each>
      </table>
      <button class="oc-head tlt">More</button>
      <div class="oc-body">
	<xsl:for-each select="../x:pids/x:pid">
	  <div>
	    <h5>Process <xsl:value-of select="."/></h5>
	<table>
	  <tr>
	    <td><span class="tlt">Command line</span>:</td>
	    <td class="xc-sl-poll" data-poll-url="/main/plain_ps?pid={.}&amp;fields=command"
		data-postprocess="psSingleField"
		data-poll-method="post"
		data-poll-interval="50000">
	    </td>
	  </tr>
	  <tr>
	    <td><span class="tlt">Started</span>:</td>
	    <td class="xc-sl-poll" data-poll-url="/main/plain_ps?pid={.}&amp;fields=lstart"
		data-postprocess="psSingleField"
		data-poll-method="post"
		data-poll-interval="50000">
	    </td>
	  </tr>
	</table>
	  </div>
	</xsl:for-each>
      </div>
    </div>
  </xsl:template>
  
  <xsl:template match="x:lpid">
    <tr>
      <td><span class="tlt">Command line</span>:</td>
      <td class="xc-sl-poll" data-poll-url="/main/plain_ps?pid={.}&amp;fields=command"
	  data-postprocess="psSingleField"
	  id="meas-command"
	  data-poll-method="post"
	  data-poll-interval="50000">
      </td>
    </tr>
    <tr>
      <td><span class="tlt">Started</span>:</td>
      <td class="xc-sl-poll" data-poll-url="/main/plain_ps?pid={.}&amp;fields=lstart"
	  data-postprocess="psSingleField"
	  id="meas-lstart"
	  data-poll-method="post"
	  data-poll-interval="50000">
      </td>
    </tr>
  </xsl:template>
  
  <xsl:template match="x:fpid">
    <tr>
      <td><span class="tlt">Command line</span>:</td>
      <td class="xc-sl-poll" data-poll-url="/main/plain_ps?pid={.}&amp;fields=command"
	  data-postprocess="psSingleField"
	  id="meas-command"
	  data-poll-method="post"
	  data-poll-interval="50000">
      </td>
    </tr>
    <tr>
      <td><span class="tlt">Started</span>:</td>
      <td class="xc-sl-poll" data-poll-url="/main/plain_ps?pid={.}&amp;fields=lstart"
	  data-postprocess="psSingleField"
	  id="meas-lstart"
	  data-poll-method="post"
	  data-poll-interval="50000">
      </td>
    </tr>
  </xsl:template>
  
</xsl:stylesheet>
